summaryrefslogtreecommitdiffstats
path: root/src/com/vaadin/ui/Root.java
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2011-12-22 11:23:20 +0200
committerLeif Åstrand <leif@vaadin.com>2011-12-22 11:23:29 +0200
commitd9f5e4c8054fa3d99f30640c9ac44eb8e850fe50 (patch)
tree854afe6fe9ed82d2f85cf43a2468b88a2594adda /src/com/vaadin/ui/Root.java
parentbf94e8c41705d1ff5e71f8a757e7a1789bf40aa0 (diff)
downloadvaadin-framework-d9f5e4c8054fa3d99f30640c9ac44eb8e850fe50.tar.gz
vaadin-framework-d9f5e4c8054fa3d99f30640c9ac44eb8e850fe50.zip
Change the default to a two request bootstrap
Add @EagerInit annotation to indicate that that no browser details are required, enabling a one request bootstrap.
Diffstat (limited to 'src/com/vaadin/ui/Root.java')
-rw-r--r--src/com/vaadin/ui/Root.java25
1 files changed, 18 insertions, 7 deletions
diff --git a/src/com/vaadin/ui/Root.java b/src/com/vaadin/ui/Root.java
index 1a67edebde..4998baf90f 100644
--- a/src/com/vaadin/ui/Root.java
+++ b/src/com/vaadin/ui/Root.java
@@ -18,7 +18,7 @@ import java.util.List;
import java.util.Map;
import com.vaadin.Application;
-import com.vaadin.annotations.RootInitRequiresBrowserDetails;
+import com.vaadin.annotations.EagerInit;
import com.vaadin.event.Action;
import com.vaadin.event.Action.Handler;
import com.vaadin.event.ActionManager;
@@ -60,9 +60,10 @@ import com.vaadin.ui.Window.CloseListener;
* {@link #setContent(ComponentContainer)}.
* </p>
* <p>
* If a {@link RootInitRequiresBrowserDetails} annotation is present on a class
* extending <code>Root</code>, the framework will ensure {@link BrowserDetails}
* are present in the {@link WrappedRequest} passed to the init method.
* </p>
*
* @see #init(WrappedRequest)
@@ -193,6 +194,15 @@ public abstract class Root extends AbstractComponentContainer implements
* Helper class to emulate the main window from Vaadin 6 using roots. This
* class should be used in the same way as Window used as a browser level
* window in Vaadin 6 together with {@Application.LegacyApplication
+ *
+ *
+ *
+ *
+ *
+ *
+ *
+ *
+ *
* }
*/
@Deprecated
@@ -1092,9 +1102,10 @@ public abstract class Root extends AbstractComponentContainer implements
* <p>
* The {@link WrappedRequest} can be used to get information about the
* request that caused this root to be created. By default, the
- * {@link BrowserDetails} are note guaranteed to be available in the
- * request. Availability of the browser details can be requested by adding
- * the {@link RootInitRequiresBrowserDetails} annotation to the class.
+ * {@link BrowserDetails} will be available in the request. If the browser
+ * details are not required, loading the application in the browser can take
+ * some shortcuts giving a faster initial rendering. This can be indicated
+ * by adding the {@link EagerInit} annotation to the Root class.
* </p>
*
* @param request
@@ -60,9 +60,10 @@ import com.vaadin.ui.Window.CloseListener;
* </p>
* <p>
- * If a {@link RootInitRequiresBrowserDetails} annotation is present on a class
- * extending <code>Root</code>, the framework will ensure {@link BrowserDetails}
- * are present in the {@link WrappedRequest} passed to the init method.
+ * If a {@link EagerInit} annotation is present on a class extending
+ * <code>Root</code>, the framework will use a faster initialization method
+ * which will not ensure that {@link BrowserDetails} are present in the
+ * {@link WrappedRequest} passed to the init method.
* </p>
*